@@ -32,6 +32,7 @@ describe 'tempest' do
 
       it 'configures image_ref' do
         is_expected.to contain_tempest_config('compute/image_ref').with_value('4c423fc6-87f7-4e6d-9d3c-abc13058ae5b')
+        is_expected.to contain_tempest_config('heat_plugin/minimal_image_ref').with_value('4c423fc6-87f7-4e6d-9d3c-abc13058ae5b')
       end
     end
 
@@ -43,6 +44,7 @@ describe 'tempest' do
 
       it 'uses a resource to configure image_ref from image_name' do
         is_expected.to contain_tempest_glance_id_setter('compute/image_ref').with_image_name('cirros')
+        is_expected.to contain_tempest_glance_id_setter('heat_plugin/minimal_image_ref').with_image_name('cirros')
       end
     end
 
@@ -149,6 +151,7 @@ describe 'tempest' do
         { :configure_images    => true,
           :image_name          => 'image name',
           :image_name_alt      => 'image name alt',
+          :heat_image_name     => 'heat image name',
           :public_network_name => 'network name',
           :neutron_available   => true,
           :install_from_source => true,
@@ -205,8 +208,6 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('auth/admin_system').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
-          is_expected.to contain_tempest_config('dns/nameservers').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/change_password_available').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute/flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref').with(:value => nil)
@@ -214,8 +215,6 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
           is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => false)
-          is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
-          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
@@ -226,20 +225,23 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/alt_password').with_secret( true )
           is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/alt_project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/alt_user_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/password').with_secret( true )
           is_expected.to contain_tempest_config('identity/project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/user_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/uri').with(:value => nil)
           is_expected.to contain_tempest_config('identity/uri_v3').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
-          is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
-          is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => nil)
+          is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
@@ -251,7 +253,6 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/heat').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
-          is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => false)
           is_expected.to contain_tempest_config('service_available/bgpvpn').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
@@ -265,28 +266,62 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/swift').with(:value => false)
           is_expected.to contain_tempest_config('service_available/trove').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ironic').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/ironic_inspector').with(:value => false)
           is_expected.to contain_tempest_config('service_available/watcher').with(:value => false)
           is_expected.to contain_tempest_config('service_available/zaqar').with(:value => false)
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
           is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
           is_expected.to contain_tempest_config('service_available/barbican').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/manila').with(:value => false)
           is_expected.to contain_tempest_config('enforce_scope/cinder').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/glance').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/keystone').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity-feature-enabled/enforce_scope').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/neutron').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/nova').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/placement').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/ironic').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/ironic_inspector').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/designate').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/octavia').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/manila').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('dns/nameservers').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('aws/ec2_url').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('aws/aws_region').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('aws/image_id').with(:value => nil)
+          is_expected.to contain_tempest_config('aws/ebs_image_id').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/auth_url').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/auth_version').with(:value => '3')
+          is_expected.to contain_tempest_config('heat_plugin/admin_password').with_secret( true )
+          is_expected.to contain_tempest_config('heat_plugin/admin_project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/admin_project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/password').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/password').with_secret( true )
+          is_expected.to contain_tempest_config('heat_plugin/project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/username').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/image_ref').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/instance_type').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/minimal_image_ref').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/minimal_instance_type').with(:value => nil)
+          is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
+          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
           is_expected.to contain_tempest_config('load_balancer/member_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/admin_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/observer_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/global_observer_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/test_with_noop').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
+          is_expected.to contain_tempest_config('share/multitenancy_enabled').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/enable_protocols').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/multi_backend').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/capability_storage_protocol').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
           is_expected.to contain_oslo__concurrency('tempest_config').with(
             :lock_path => '/var/lib/tempest'
           )
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/var/lib/tempest/cirros-0.4.0-x86_64-disk.img')
+          is_expected.to contain_tempest_config('scenario/img_disk_format').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
           is_expected.to contain_oslo__log('tempest_config').with(
             :debug => false,
@@ -305,12 +340,21 @@ describe 'tempest' do
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :image_name        => 'image name',
           )
-
           is_expected.to contain_tempest_glance_id_setter('compute/image_ref_alt').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :image_name        => 'image name alt',
           )
+          is_expected.to contain_tempest_glance_id_setter('heat_plugin/image_ref').with(
+            :ensure            => 'present',
+            :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+            :image_name        => 'heat image name',
+          )
+          is_expected.to contain_tempest_glance_id_setter('heat_plugin/minimal_image_ref').with(
+            :ensure            => 'present',
+            :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+            :image_name        => 'image name',
+          )
         end
 
         it 'neutron net id' do
@@ -390,6 +434,7 @@ describe 'tempest' do
           :flavor_name      => 'm1.tiny',
           :flavor_name_alt  => 'm1.nano',
           :db_flavor_name   => 'm1.micro',
+          :heat_flavor_name => 'm1.small',
         }
       end
 
@@ -409,6 +454,16 @@ describe 'tempest' do
           :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
           :flavor_name       => 'm1.micro',
         )
+        is_expected.to contain_tempest_flavor_id_setter('heat_plugin/instance_type').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.small',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('heat_plugin/minimal_instance_type').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.tiny',
+        )
       end
     end
   end
@@ -467,12 +522,10 @@ describe 'tempest' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :concat_basedir => '/var/lib/puppet/concat',
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :dev_packages          => ['python3-dev',
                                        'libxslt1-dev',
@@ -505,7 +558,7 @@ describe 'tempest' do
       end
 
       it_behaves_like 'tempest'
-      if facts[:operatingsystem] != 'Ubuntu'
+      if facts[:os]['name'] != 'Ubuntu'
         it_behaves_like 'tempest with plugins packages'
       end
     end
